module.exports={A:{A:{"2":"H D G E A B nB"},B:{"1":"q","2":"C K f L N I J"},C:{"1":"0 1 2 3 4 5 6 8 l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB","164":"OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k eB dB"},D:{"1":"HB IB JB KB LB MB cB QB XB TB q sB UB VB","292":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB"},E:{"1":"9 K fB","292":"7 F O H D G E A B C WB RB YB ZB aB bB PB"},F:{"2":"7 9 E B C gB hB iB jB GB lB","292":"0 1 2 3 4 5 6 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z"},G:{"1":"zB 0B 1B 2B","292":"G RB mB CB oB pB qB rB SB tB uB vB wB xB yB"},H:{"2":"3B"},I:{"1":"QB","292":"OB F 4B 5B 6B 7B CB 8B 9B"},J:{"292":"D A"},K:{"2":"7 9 A B C GB","292":"M"},L:{"1":"q"},M:{"1":"8"},N:{"2":"A B"},O:{"292":"AC"},P:{"1":"PB","292":"F BC CC DC EC FC"},Q:{"292":"GC"},R:{"292":"HC"},S:{"1":"IC"}},B:5,C:"CSS Logical Properties"};
