module.exports={A:{A:{"1":"A B","2":"nB","8":"H D G E"},B:{"1":"C K f L N I J q"},C:{"1":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB eB dB","8":"kB OB"},D:{"1":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"1":"7 9 F O H D G E A B C K YB ZB aB bB PB fB","8":"WB RB"},F:{"1":"0 1 2 3 4 5 6 7 9 B C L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z jB GB lB","2":"E gB","8":"hB iB"},G:{"1":"G oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B","2":"RB mB CB"},H:{"2":"3B"},I:{"1":"QB 4B 8B 9B","2":"OB F 5B 6B 7B CB"},J:{"1":"D A"},K:{"1":"7 9 B C M GB","8":"A"},L:{"1":"q"},M:{"1":"8"},N:{"1":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:1,C:"Web Workers"};
