module.exports={A:{A:{"2":"H D G E A B nB"},B:{"2":"C K f L N I J","33":"q"},C:{"2":"0 1 2 3 4 5 6 8 kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB eB dB"},D:{"2":"F O H D G E A B C K f L N","33":"0 1 2 3 4 5 6 8 I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"1":"7 9 A B C K PB fB","2":"F O WB RB","33":"H D G E YB ZB aB bB"},F:{"2":"7 9 E B C gB hB iB jB GB lB","33":"0 1 2 3 4 5 6 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z"},G:{"1":"uB vB wB xB yB zB 0B 1B 2B","2":"RB mB CB","33":"G oB pB qB rB SB tB"},H:{"2":"3B"},I:{"2":"OB F 4B 5B 6B 7B CB","33":"QB 8B 9B"},J:{"2":"D A"},K:{"2":"7 9 A B C GB","33":"M"},L:{"33":"q"},M:{"2":"8"},N:{"2":"A B"},O:{"33":"AC"},P:{"33":"F BC CC DC EC FC PB"},Q:{"33":"GC"},R:{"33":"HC"},S:{"2":"IC"}},B:7,C:"CSS Cross-Fade Function"};
