module.exports={A:{A:{"2":"H D G E nB","132":"A B"},B:{"1":"C K f L N I J q"},C:{"1":"0 1 2 3 4 5 6 8 N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB F O H D G E eB dB","33":"A B C K f L"},D:{"1":"0 1 2 3 4 5 6 8 g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F O H D G E A B","33":"C K f L N I J P Q R S T U V W X Y Z a b c d e AB"},E:{"2":"WB RB","33":"F O H D G YB ZB aB","257":"7 9 E A B C K bB PB fB"},F:{"1":"0 1 2 3 4 5 6 T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","2":"7 9 E B C gB hB iB jB GB lB","33":"L N I J P Q R S"},G:{"33":"G RB mB CB oB pB qB rB","257":"SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"1":"QB","2":"4B 5B 6B","33":"OB F 7B CB 8B 9B"},J:{"33":"D A"},K:{"1":"M","2":"7 9 A B C GB"},L:{"1":"q"},M:{"1":"8"},N:{"132":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:5,C:"CSS3 3D Transforms"};
