module.exports={A:{A:{"1":"A B","2":"H D G E nB"},B:{"1":"q","2":"C K f L N I J"},C:{"1":"0 1 2 3 4 5 6 8 h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB eB dB","132":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g"},D:{"1":"0 1 2 3 4 5 6 8 W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F","16":"O H D G R S T U V","132":"E A B C K f L N I J P Q"},E:{"1":"7 9 C K fB","2":"F O WB RB YB","132":"H D G E A B ZB aB bB PB"},F:{"1":"0 1 2 3 4 5 6 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","2":"7 9 E B C gB hB iB jB GB lB"},G:{"2":"pB qB","132":"G rB SB tB uB vB wB xB yB zB 0B 1B 2B","514":"RB mB CB oB"},H:{"2":"3B"},I:{"2":"4B 5B 6B","260":"OB F 7B CB","514":"QB 8B 9B"},J:{"132":"A","260":"D"},K:{"2":"7 9 A B C GB","260":"M"},L:{"260":"q"},M:{"2":"8"},N:{"514":"A","1028":"B"},O:{"2":"AC"},P:{"260":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"260":"HC"},S:{"1":"IC"}},B:1,C:"accept attribute for file input"};
