module.exports={A:{A:{"2":"H D G E A B nB"},B:{"2":"C K f L N I J q"},C:{"2":"4 5 6 8 kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y NB DB BB FB HB IB JB KB LB MB eB dB","66":"0 1 2 3 Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB"},D:{"1":"0 1 2 3 4 5 6 8 AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q","2":"F O H D G E A B C K f L N I J P Q R S T U sB UB VB","33":"V W X Y Z a b c d e"},E:{"2":"7 9 F O H D G E A B C K WB RB YB ZB aB bB PB fB"},F:{"1":"0 1 2 3 4 5 6 S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","2":"7 9 E B C gB hB iB jB GB lB","33":"L N I J P Q R"},G:{"2":"G RB mB CB oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"2":"OB F QB 4B 5B 6B 7B CB","33":"8B 9B"},J:{"2":"D A"},K:{"1":"M","2":"7 9 A B C GB"},L:{"2":"q"},M:{"2":"8"},N:{"2":"A B"},O:{"1":"AC"},P:{"1":"BC CC DC EC FC PB","33":"F"},Q:{"1":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:7,C:"Shadow DOM (deprecated V0 spec)"};
