module.exports={A:{A:{"2":"H D G E A B nB"},B:{"1":"I J q","2":"C K f","322":"L N"},C:{"1":"0 1 2 4 5 6 8 o M r s t u v x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c eB dB","194":"d e AB g h i j k l m n","513":"3 p w"},D:{"1":"0 1 2 3 4 5 6 8 p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j","4":"k l m n o"},E:{"1":"7 9 C K fB","2":"F O H D G E A B WB RB YB ZB aB bB PB"},F:{"1":"0 1 2 3 4 5 6 c d e AB g h i j k l m n o p M r s t u v w x y z","2":"7 9 E B C L N I J P Q R S T U V W gB hB iB jB GB lB","4":"X Y Z a b"},G:{"1":"xB yB zB 0B 1B 2B","2":"G RB mB CB oB pB qB rB SB tB uB vB wB"},H:{"2":"3B"},I:{"2":"OB F 4B 5B 6B 7B CB 8B 9B","4":"QB"},J:{"2":"D A"},K:{"2":"7 9 A B C GB","4":"M"},L:{"1":"q"},M:{"1":"8"},N:{"2":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"4":"GC"},R:{"4":"HC"},S:{"2":"IC"}},B:5,C:"Service Workers"};
