module.exports={A:{A:{"2":"nB","8":"H D G","129":"A B","161":"E"},B:{"1":"I J q","129":"C K f L N"},C:{"1":"0 1 2 3 4 5 6 8 N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB","33":"F O H D G E A B C K f L eB dB"},D:{"1":"0 1 2 3 4 5 6 8 g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","33":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB"},E:{"1":"7 9 E A B C K bB PB fB","33":"F O H D G WB RB YB ZB aB"},F:{"1":"0 1 2 3 4 5 6 9 T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","2":"E gB hB","33":"7 B C L N I J P Q R S iB jB GB lB"},G:{"1":"SB tB uB vB wB xB yB zB 0B 1B 2B","33":"G RB mB CB oB pB qB rB"},H:{"2":"3B"},I:{"1":"QB","33":"OB F 4B 5B 6B 7B CB 8B 9B"},J:{"33":"D A"},K:{"1":"7 9 B C M GB","2":"A"},L:{"1":"q"},M:{"1":"8"},N:{"1":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:5,C:"CSS3 2D Transforms"};
