module.exports={A:{A:{"2":"H D G nB","8":"E A B"},B:{"1":"I J q","8":"C K f L N"},C:{"1":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB eB dB","2":"kB OB"},D:{"1":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"2":"7 9 F O H D G E A B C K WB RB YB ZB aB bB PB fB"},F:{"1":"0 1 2 3 4 5 6 7 9 B C L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z iB jB GB lB","2":"E gB hB"},G:{"2":"G RB mB CB oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"2":"OB F QB 4B 5B 6B 7B CB 8B 9B"},J:{"2":"D A"},K:{"2":"7 9 A B C M GB"},L:{"2":"q"},M:{"1":"8"},N:{"8":"A B"},O:{"1":"AC"},P:{"2":"F BC CC DC EC FC PB"},Q:{"2":"GC"},R:{"2":"HC"},S:{"1":"IC"}},B:6,C:"Ogg/Theora video format"};
