module.exports={A:{A:{"2":"nB","4":"A B","8":"H D G E"},B:{"1":"N I J q","4":"C K f L"},C:{"4":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","8":"kB OB eB dB"},D:{"1":"4 5 6 8 NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","4":"0 1 2 3 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB"},E:{"4":"7 9 F O H D G E A B C K YB ZB aB bB PB fB","8":"WB RB"},F:{"1":"0 1 2 3 4 5 6 7 9 E B C w x y z gB hB iB jB GB lB","4":"L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v"},G:{"2":"RB","4":"G mB CB oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"1":"QB","2":"OB F 4B 5B 6B 7B CB","4":"8B 9B"},J:{"2":"D","4":"A"},K:{"1":"7 9 A B C GB","4":"M"},L:{"1":"q"},M:{"4":"8"},N:{"4":"A B"},O:{"1":"AC"},P:{"1":"EC FC PB","4":"F BC CC DC"},Q:{"4":"GC"},R:{"4":"HC"},S:{"4":"IC"}},B:1,C:"HTML5 form features"};
