module.exports={A:{A:{"1":"E A B","2":"nB","8":"H D G"},B:{"1":"C K f L N I J","129":"q"},C:{"1":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y eB dB","8":"kB OB","129":"0 1 2 3 4 5 6 8 z EB NB DB BB FB HB IB JB KB LB MB"},D:{"1":"O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t","4":"F","129":"0 1 2 3 4 5 6 8 u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"1":"7 9 O H D G E B C K YB ZB aB bB PB fB","8":"F WB RB","129":"A"},F:{"1":"7 9 B C N I J P Q R S T U V W X Y Z a b c d e AB g h i jB GB lB","2":"E L gB","8":"hB iB","129":"0 1 2 3 4 5 6 j k l m n o p M r s t u v w x y z"},G:{"1":"G RB mB CB oB pB qB rB SB tB","129":"uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"1":"OB F 4B 5B 6B 7B CB 8B 9B","129":"QB"},J:{"1":"D A"},K:{"1":"7 9 B C M GB","8":"A"},L:{"129":"q"},M:{"129":"8"},N:{"1":"A B"},O:{"1":"AC"},P:{"1":"F","129":"BC CC DC EC FC PB"},Q:{"129":"GC"},R:{"129":"HC"},S:{"1":"IC"}},B:2,C:"Geolocation"};
