module.exports={A:{A:{"1":"B","2":"H D nB","66":"G E A"},B:{"1":"C K f L N I J q"},C:{"1":"0 1 2 3 4 5 6 8 X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB F O H D G E A B C K f L N I J P Q R S T eB dB","66":"U V W"},D:{"1":"0 1 2 3 4 5 6 8 a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z"},E:{"1":"7 9 D G E A B C K aB bB PB fB","2":"F O H WB RB YB ZB"},F:{"1":"0 1 2 3 4 5 6 9 I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","2":"E L N gB","66":"7 B C hB iB jB GB lB"},G:{"1":"G oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B","2":"RB mB CB"},H:{"1":"3B"},I:{"1":"QB","2":"OB F 4B 5B 6B 7B CB 8B 9B"},J:{"1":"A","2":"D"},K:{"1":"9 M","2":"7 A B C GB"},L:{"1":"q"},M:{"1":"8"},N:{"1":"B","66":"A"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:6,C:"TLS 1.2"};
