module.exports={A:{A:{"2":"H D G E A B nB"},B:{"2":"C K f L N I J","33":"q"},C:{"1":"0 1 2 3 4 5 6 8 u v w x y z EB NB DB BB FB HB IB JB KB LB MB","16":"kB OB F O H D G E A B C K f L N I J P Q eB dB","33":"R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t"},D:{"16":"F O H D G E A B C K f L N I J P Q R S T","33":"0 1 2 3 4 5 6 8 U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"16":"F O H WB RB YB","33":"7 9 D G E A B C K ZB aB bB PB fB"},F:{"2":"7 9 E B C gB hB iB jB GB lB","33":"0 1 2 3 4 5 6 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z"},G:{"16":"RB mB CB oB","33":"G pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"16":"OB F 4B 5B 6B 7B CB 8B 9B","33":"QB"},J:{"16":"D A"},K:{"2":"7 9 A B C GB","33":"M"},L:{"33":"q"},M:{"33":"8"},N:{"2":"A B"},O:{"16":"AC"},P:{"16":"F","33":"BC CC DC EC FC PB"},Q:{"33":"GC"},R:{"33":"HC"},S:{"33":"IC"}},B:5,C:"CSS :any-link selector"};
