module.exports={A:{A:{"2":"H D G E A nB","132":"B"},B:{"1":"C K f L N I J","513":"q"},C:{"1":"g h i j k l m n o p M r s t u v w","2":"kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB eB dB","513":"0 1 2 3 4 5 6 8 x y z EB NB DB BB FB HB IB JB KB LB MB"},D:{"1":"l m n o p M r s t u","2":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k","513":"0 1 2 3 4 5 6 8 v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"1":"7 9 B C K fB","2":"F O H D G WB RB YB ZB aB","260":"E A bB PB"},F:{"1":"Y Z a b c d e AB g h","2":"7 9 E B C L N I J P Q R S T U V W X gB hB iB jB GB lB","513":"0 1 2 3 4 5 6 i j k l m n o p M r s t u v w x y z"},G:{"1":"SB tB uB vB wB xB yB zB 0B 1B 2B","2":"G RB mB CB oB pB qB rB"},H:{"2":"3B"},I:{"2":"OB F 4B 5B 6B 7B CB 8B 9B","513":"QB"},J:{"2":"D A"},K:{"1":"M","2":"7 9 A B C GB"},L:{"513":"q"},M:{"513":"8"},N:{"2":"A B"},O:{"1":"AC"},P:{"1":"F","513":"BC CC DC EC FC PB"},Q:{"513":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:6,C:"HTTP/2 protocol"};
