module.exports={A:{A:{"1":"B","4":"H D G E A nB"},B:{"1":"C K f L N","129":"I J q"},C:{"1":"H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u","4":"kB OB F O eB dB","129":"0 1 2 3 4 5 6 8 v w x y z EB NB DB BB FB HB IB JB KB LB MB"},D:{"1":"p M r s t u v w x y","4":"F O H","129":"0 1 2 3 4 5 6 8 D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"4":"F O WB RB","129":"7 9 H D G E A B C K YB ZB aB bB PB fB"},F:{"1":"7 9 C c d e AB g h i j k l GB lB","4":"E B gB hB iB jB","129":"0 1 2 3 4 5 6 L N I J P Q R S T U V W X Y Z a b m n o p M r s t u v w x y z"},G:{"4":"RB mB CB","129":"G oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"4":"3B"},I:{"4":"4B 5B 6B","129":"OB F QB 7B CB 8B 9B"},J:{"129":"D A"},K:{"1":"7 9 C GB","4":"A B","129":"M"},L:{"129":"q"},M:{"129":"8"},N:{"1":"B","4":"A"},O:{"129":"AC"},P:{"129":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"129":"HC"},S:{"1":"IC"}},B:1,C:"dataset & data-* attributes"};
