module.exports={A:{A:{"1":"E A B","16":"nB","260":"H D G"},B:{"1":"C K f L N I J q"},C:{"1":"0 1 2 3 4 5 6 8 w x y z EB NB DB BB FB HB IB JB KB LB MB","132":"kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m eB dB","2180":"n o p M r s t u v"},D:{"1":"0 1 2 3 4 5 6 8 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","16":"F O H D G E A B C K f"},E:{"1":"7 9 H D G E A B C K YB ZB aB bB PB fB","16":"F O WB RB"},F:{"1":"0 1 2 3 4 5 6 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","132":"7 9 E B C gB hB iB jB GB lB"},G:{"16":"CB","132":"RB mB","516":"G oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"1":"QB 8B 9B","16":"OB F 4B 5B 6B 7B","1025":"CB"},J:{"1":"A","16":"D"},K:{"1":"M","16":"7 A B C GB","132":"9"},L:{"1":"q"},M:{"1":"8"},N:{"1":"B","16":"A"},O:{"1025":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"2180":"IC"}},B:5,C:"Selection API"};
