module.exports={A:{A:{"2":"H D G E A B nB"},B:{"1":"K f L N I J q","2":"C"},C:{"16":"kB","33":"0 1 2 3 4 5 6 8 OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB eB dB"},D:{"1":"0 1 2 3 4 5 6 8 g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","16":"F O H D G E A B C K f","132":"L N I J P Q R S T U V W X Y Z a b c d e AB"},E:{"1":"7 9 E A B C K bB PB fB","16":"WB RB","132":"F O H D G YB ZB aB"},F:{"1":"0 1 2 3 4 5 6 T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","16":"7 E B gB hB iB jB","132":"9 C L N I J P Q R S GB lB"},G:{"1":"SB tB uB vB wB xB yB zB 0B 1B 2B","16":"RB mB","132":"G CB oB pB qB rB"},H:{"2":"3B"},I:{"1":"QB","16":"4B 5B","132":"OB F 6B 7B CB 8B 9B"},J:{"1":"A","132":"D"},K:{"1":"M","2":"7 A B","132":"9 C GB"},L:{"1":"q"},M:{"33":"8"},N:{"2":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"33":"IC"}},B:1,C:"CSS :read-only and :read-write selectors"};
