module.exports={A:{A:{"4":"H D G E A B nB"},B:{"4":"C K f L N I J q"},C:{"1":"0 1 2 3 4 5 6 8 i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","8":"kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h eB dB"},D:{"4":"0 1 2 3 4 5 6 8 O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","8":"F"},E:{"4":"7 9 O H D G E A B C K YB ZB aB bB PB fB","8":"F WB RB"},F:{"4":"0 1 2 3 4 5 6 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","8":"7 9 E B C gB hB iB jB GB lB"},G:{"4":"G oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B","8":"RB mB CB"},H:{"8":"3B"},I:{"4":"OB F QB 7B CB 8B 9B","8":"4B 5B 6B"},J:{"4":"A","8":"D"},K:{"4":"M","8":"7 9 A B C GB"},L:{"4":"q"},M:{"1":"8"},N:{"4":"A B"},O:{"4":"AC"},P:{"4":"F BC CC DC EC FC PB"},Q:{"4":"GC"},R:{"4":"HC"},S:{"1":"IC"}},B:1,C:"Ruby annotation"};
