module.exports={A:{A:{"2":"H D G E A B nB"},B:{"1":"q","2":"C K f L N I J"},C:{"2":"kB OB eB dB","33":"0 1 2 3 4 5 6 8 x y z EB NB DB BB FB HB IB JB KB LB MB","164":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w"},D:{"1":"0 1 2 3 4 5 6 8 m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F O H D G E A B C K f L N I J P Q","132":"R S T U V W X Y Z a b c d e AB g h i j k l"},E:{"1":"fB","2":"F O H WB RB YB","132":"7 9 D G E A B C K ZB aB bB PB"},F:{"1":"0 1 2 3 4 5 6 Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","2":"E gB hB iB","132":"L N I J P Q R S T U V W X Y","164":"7 9 B C jB GB lB"},G:{"2":"RB mB CB oB pB","132":"G qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"164":"3B"},I:{"1":"QB","2":"OB F 4B 5B 6B 7B CB","132":"8B 9B"},J:{"132":"D A"},K:{"1":"M","2":"A","164":"7 9 B C GB"},L:{"1":"q"},M:{"33":"8"},N:{"2":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"164":"IC"}},B:5,C:"CSS3 tab-size"};
