module.exports={A:{A:{"1":"A B","2":"H D G E nB"},B:{"1":"C K f L N I J q"},C:{"1":"0 1 2 3 4 5 6 8 N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB eB dB","33":"O H D G E A B C K f L","164":"F"},D:{"1":"0 1 2 3 4 5 6 8 W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","33":"F O H D G E A B C K f L N I J P Q R S T U V"},E:{"1":"7 9 D G E A B C K ZB aB bB PB fB","33":"H YB","164":"F O WB RB"},F:{"1":"0 1 2 3 4 5 6 9 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","2":"E gB hB","33":"C","164":"7 B iB jB GB lB"},G:{"1":"G qB rB SB tB uB vB wB xB yB zB 0B 1B 2B","33":"pB","164":"RB mB CB oB"},H:{"2":"3B"},I:{"1":"QB 8B 9B","33":"OB F 4B 5B 6B 7B CB"},J:{"1":"A","33":"D"},K:{"1":"9 M","33":"C","164":"7 A B GB"},L:{"1":"q"},M:{"1":"8"},N:{"1":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:5,C:"CSS3 Transitions"};
