module.exports={A:{A:{"2":"H D G nB","388":"E A B"},B:{"4":"q","260":"C K f L N I J"},C:{"1":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB eB dB","2":"kB","4":"OB"},D:{"4":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"2":"WB RB","4":"7 9 F O H D G E A B C K YB ZB aB bB PB fB"},F:{"4":"0 1 2 3 4 5 6 7 9 E B C L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z gB hB iB jB GB lB"},G:{"4":"G RB mB CB oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"2":"OB F 4B 5B 6B 7B CB","4":"QB 8B 9B"},J:{"1":"A","2":"D"},K:{"4":"7 9 A B C M GB"},L:{"4":"q"},M:{"1":"8"},N:{"2":"A B"},O:{"2":"AC"},P:{"4":"F BC CC DC EC FC PB"},Q:{"4":"GC"},R:{"4":"HC"},S:{"1":"IC"}},B:2,C:"SVG effects for HTML"};
