module.exports={A:{A:{"1":"A B","260":"H D G E nB"},B:{"1":"C K f L N I J q"},C:{"1":"0 1 2 3 4 5 6 8 C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","132":"B","260":"kB OB F O H D eB dB","516":"G E A"},D:{"1":"0 1 2 3 4 5 6 8 b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","132":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a"},E:{"1":"7 9 G E A B C K aB bB PB fB","132":"F O H D WB RB YB ZB"},F:{"1":"0 1 2 3 4 5 6 J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","16":"E gB","132":"7 9 B C L N I hB iB jB GB lB"},G:{"1":"G rB SB tB uB vB wB xB yB zB 0B 1B 2B","132":"RB mB CB oB pB qB"},H:{"132":"3B"},I:{"1":"QB 8B 9B","132":"OB F 4B 5B 6B 7B CB"},J:{"132":"D A"},K:{"1":"M","16":"A","132":"7 9 B C GB"},L:{"1":"q"},M:{"1":"8"},N:{"1":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:4,C:"DOM Parsing and Serialization"};
