module.exports={A:{A:{"2":"H D G E A B nB"},B:{"2":"C K f L N I J","2052":"q"},C:{"2":"kB OB F O eB dB","1028":"0 1 2 3 4 5 6 8 g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","1060":"H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB"},D:{"2":"F O H D G E A B C K f L N I J P Q R S T U V","226":"0 W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","2052":"1 2 3 4 5 6 8 EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"2":"F O H D WB RB YB ZB","772":"9 K fB","804":"7 G E A B C bB PB","1316":"aB"},F:{"2":"7 9 E B C L N I J P Q R S T U V W X Y Z a b c d e gB hB iB jB GB lB","226":"AB g h i j k l m n","2052":"0 1 2 3 4 5 6 o p M r s t u v w x y z"},G:{"2":"RB mB CB oB pB qB","292":"G rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"1":"QB","2":"OB F 4B 5B 6B 7B CB 8B 9B"},J:{"2":"D A"},K:{"2":"7 9 A B C GB","2052":"M"},L:{"2052":"q"},M:{"1":"8"},N:{"2":"A B"},O:{"2052":"AC"},P:{"2":"F BC CC","2052":"DC EC FC PB"},Q:{"2":"GC"},R:{"1":"HC"},S:{"1028":"IC"}},B:4,C:"text-decoration styling"};
