module.exports={A:{A:{"2":"H D G E A B nB"},B:{"2":"C K f L N I J","260":"q"},C:{"2":"kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c eB dB","260":"3 4 5 6 8 EB NB DB BB FB HB IB JB KB LB MB","516":"0 1 2 r s t u v w x y z","580":"d e AB g h i j k l m n o p M"},D:{"2":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB","132":"g h i","260":"0 1 2 3 4 5 6 8 j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"2":"F O H D G E A WB RB YB ZB aB bB PB","4":"fB","1090":"7 9 B C K"},F:{"2":"7 9 E B C L N I J P Q R S gB hB iB jB GB lB","132":"T U V","260":"0 1 2 3 4 5 6 W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z"},G:{"2":"G RB mB CB oB pB qB rB SB tB uB vB","4":"zB 0B 1B 2B","1090":"wB xB yB"},H:{"2":"3B"},I:{"2":"OB F 4B 5B 6B 7B CB 8B 9B","260":"QB"},J:{"2":"D A"},K:{"2":"7 9 A B C GB","260":"M"},L:{"260":"q"},M:{"1":"8"},N:{"2":"A B"},O:{"260":"AC"},P:{"260":"F BC CC DC EC FC PB"},Q:{"260":"GC"},R:{"260":"HC"},S:{"516":"IC"}},B:5,C:"Web Animations API"};
