module.exports={A:{A:{"2":"H D G nB","8":"E A B"},B:{"1":"q","4":"f L N I J","8":"C K"},C:{"1":"0 1 2 3 4 5 6 8 Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB eB dB","4":"F O H D G E A B C K f L N I J P Q R S T U V W X"},D:{"1":"0 1 2 3 4 5 6 8 V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F O","4":"H D G E A B C K f L N I J P Q R S T U"},E:{"2":"WB","8":"7 F O H D G E A B C RB YB ZB aB bB PB","132":"9 K fB"},F:{"1":"0 1 2 3 4 5 6 N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","2":"E gB hB iB","4":"7 9 B C L jB GB lB"},G:{"2":"G RB mB CB oB pB qB rB SB tB uB vB wB xB yB","132":"zB 0B 1B 2B"},H:{"2":"3B"},I:{"1":"QB","2":"4B 5B","4":"OB F 6B 7B CB 8B 9B"},J:{"2":"D A"},K:{"2":"7 9 A B C GB","4":"M"},L:{"1":"q"},M:{"1":"8"},N:{"8":"A B"},O:{"1":"AC"},P:{"1":"BC CC DC EC FC PB","4":"F"},Q:{"1":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:6,C:"WebM video format"};
