module.exports={A:{A:{"2":"nB","8":"H D G E","260":"A B"},B:{"1":"q","260":"C K f L","1284":"N I J"},C:{"8":"kB OB eB dB","516":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB"},D:{"1":"HB IB JB KB LB MB cB QB XB TB q sB UB VB","8":"F O H D G E A B C K f L N I J P","132":"0 1 2 3 4 5 6 8 Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB"},E:{"1":"9 K fB","8":"7 F O H D G E A B C WB RB YB ZB aB bB PB"},F:{"1":"6 7 9 E B C gB hB iB jB GB lB","132":"0 1 2 3 4 5 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z"},G:{"8":"G RB mB CB oB pB qB rB SB tB uB vB wB xB yB","2049":"zB 0B 1B 2B"},H:{"2":"3B"},I:{"1":"9B","8":"OB F 4B 5B 6B 7B CB 8B","132":"QB"},J:{"1":"A","8":"D"},K:{"1":"7 9 A B C GB","8":"M"},L:{"1":"q"},M:{"516":"8"},N:{"8":"A B"},O:{"8":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"2":"IC"}},B:1,C:"Datalist element"};
