module.exports={A:{A:{"388":"A B","900":"H D G E nB"},B:{"388":"C K f L N I J","900":"q"},C:{"772":"8 DB BB FB HB IB JB KB LB MB","900":"0 1 2 3 4 5 6 kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB eB dB"},D:{"900":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"772":"A","900":"7 9 F O H D G E B C K WB RB YB ZB aB bB PB fB"},F:{"16":"E gB","129":"7 9 B C hB iB jB GB lB","900":"0 1 2 3 4 5 6 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z"},G:{"900":"G RB mB CB oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"129":"3B"},I:{"900":"OB F QB 4B 5B 6B 7B CB 8B 9B"},J:{"900":"D A"},K:{"129":"7 9 A B C GB","900":"M"},L:{"900":"q"},M:{"900":"8"},N:{"388":"A B"},O:{"900":"AC"},P:{"900":"F BC CC DC EC FC PB"},Q:{"900":"GC"},R:{"900":"HC"},S:{"900":"IC"}},B:2,C:"CSS page-break properties"};
