module.exports={A:{A:{"2":"H D G E A B nB"},B:{"1":"q","36":"C K f L N I J"},C:{"1":"0 1 2 3 4 5 6 8 v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB F O H D G E A B C K f L N I J eB dB","33":"P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u"},D:{"1":"1 2 3 4 5 6 8 EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","36":"0 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z"},E:{"1":"7 9 B C K PB fB","2":"F WB RB","36":"O H D G E A YB ZB aB bB"},F:{"1":"0 1 2 3 4 5 6 o p M r s t u v w x y z","2":"7 9 E B C gB hB iB jB GB lB","36":"L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n"},G:{"1":"vB wB xB yB zB 0B 1B 2B","2":"RB mB","36":"G CB oB pB qB rB SB tB uB"},H:{"2":"3B"},I:{"1":"QB","36":"OB F 4B 5B 6B 7B CB 8B 9B"},J:{"36":"D A"},K:{"1":"M","2":"7 9 A B C GB"},L:{"1":"q"},M:{"1":"8"},N:{"36":"A B"},O:{"1":"AC"},P:{"1":"DC EC FC PB","36":"F BC CC"},Q:{"36":"GC"},R:{"1":"HC"},S:{"33":"IC"}},B:5,C:"::placeholder CSS pseudo-element"};
