module.exports={A:{A:{"2":"H D G E nB","8":"A B"},B:{"1":"q","8":"C K f L N I J"},C:{"1":"5 6 8 DB BB FB HB IB JB KB LB MB","2":"kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z eB dB","8":"a b c d e AB g h i j k l m n o p M r s t","456":"0 1 2 u v w x y z","712":"3 4 EB NB"},D:{"1":"8 FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v","8":"w x","132":"0 1 2 3 4 5 6 y z EB NB DB BB"},E:{"2":"F O H D WB RB YB ZB aB","8":"G E A bB","132":"7 9 B C K PB fB"},F:{"1":"6","2":"7 9 E B C L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k gB hB iB jB GB lB","132":"0 1 2 3 4 5 l m n o p M r s t u v w x y z"},G:{"2":"G RB mB CB oB pB qB rB SB tB uB","132":"vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"1":"QB","2":"OB F 4B 5B 6B 7B CB 8B 9B"},J:{"2":"D A"},K:{"2":"7 9 A B C GB","132":"M"},L:{"1":"q"},M:{"1":"8"},N:{"2":"A B"},O:{"1":"AC"},P:{"1":"CC DC EC FC PB","2":"F","132":"BC"},Q:{"8":"GC"},R:{"132":"HC"},S:{"8":"IC"}},B:1,C:"Custom Elements (V1)"};
