module.exports={A:{A:{"1":"A B","2":"H D G E nB"},B:{"1":"C K f L N I J q"},C:{"1":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB dB","2":"kB OB eB"},D:{"1":"0 1 2 3 4 5 6 8 O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F"},E:{"1":"7 9 F O H D G E A B C K YB ZB aB bB PB fB","2":"WB RB"},F:{"1":"0 1 2 3 4 5 6 7 9 B C L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z jB GB lB","2":"E gB hB iB"},G:{"1":"G pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B","2":"RB mB CB oB"},H:{"130":"3B"},I:{"130":"OB F QB 4B 5B 6B 7B CB 8B 9B"},J:{"2":"D A"},K:{"130":"7 9 A B C M GB"},L:{"132":"q"},M:{"130":"8"},N:{"2":"A B"},O:{"130":"AC"},P:{"130":"F","132":"BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"132":"HC"},S:{"2":"IC"}},B:1,C:"Multiple file selection"};
