module.exports={A:{A:{"1":"A B","2":"H D G E nB"},B:{"1":"C K f L N I J q"},C:{"1":"0 1 2 3 4 5 6 8 kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB eB dB"},D:{"1":"0 1 2 3 4 5 6 8 E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F O H D G"},E:{"1":"7 9 H D G E A B C K YB ZB aB bB PB fB","2":"F O WB RB"},F:{"1":"0 1 2 3 4 5 6 7 9 B C L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z iB jB GB lB","2":"E gB hB"},G:{"4":"G RB mB CB oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"4":"3B"},I:{"4":"OB F QB 4B 5B 6B 7B CB 8B 9B"},J:{"1":"A","4":"D"},K:{"4":"7 9 A B C M GB"},L:{"4":"q"},M:{"4":"8"},N:{"4":"A B"},O:{"4":"AC"},P:{"4":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"4":"HC"},S:{"2":"IC"}},B:1,C:"Spellcheck attribute"};
