module.exports={A:{A:{"16":"H D G E A B nB"},B:{"1":"q","16":"C K f L N I J"},C:{"16":"0 1 2 3 4 5 6 8 kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB eB dB"},D:{"1":"0 1 2 3 4 5 6 8 z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","16":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y"},E:{"16":"7 9 F O H D G E A B C K WB RB YB ZB aB bB PB fB"},F:{"16":"0 1 2 3 4 5 6 7 9 E B C L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z gB hB iB jB GB lB"},G:{"16":"G RB mB CB oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"16":"3B"},I:{"16":"OB F QB 4B 5B 6B 7B CB 8B 9B"},J:{"16":"D A"},K:{"16":"7 9 A B C M GB"},L:{"16":"q"},M:{"16":"8"},N:{"16":"A B"},O:{"16":"AC"},P:{"16":"F BC CC DC EC FC PB"},Q:{"16":"GC"},R:{"16":"HC"},S:{"16":"IC"}},B:5,C:"CSS4 Hyphenation"};
