module.exports={A:{A:{"2":"H D G E A B nB"},B:{"1":"q","2":"C K f L N I J"},C:{"1":"0 1 2 3 4 5 6 8 e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB F O H D G E A B C K f L N I J P Q R S T eB dB","194":"U V W X Y Z a b c d"},D:{"1":"0 1 2 3 4 5 6 8 d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F O H D G E A B C K f L N I J P Q R S T U V W X Y","33":"Z a b c"},E:{"1":"7 9 A B C K bB PB fB","2":"F O H WB RB YB ZB","33":"D G E aB"},F:{"1":"0 1 2 3 4 5 6 Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","2":"7 9 E B C L gB hB iB jB GB lB","33":"N I J P"},G:{"2":"RB mB CB oB pB qB","33":"G rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"1":"QB 9B","2":"OB F 4B 5B 6B 7B CB","33":"8B"},J:{"2":"D","33":"A"},K:{"1":"M","2":"7 9 A B C GB"},L:{"1":"q"},M:{"1":"8"},N:{"2":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:4,C:"CSS3 font-kerning"};
