module.exports={A:{A:{"4":"H D G E A B nB"},B:{"1":"J q","4":"C K f L N I"},C:{"1":"0 1 2 3 4 5 6 8 t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB","4":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s eB dB"},D:{"1":"0 1 2 3 4 5 6 8 T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","4":"F O H D G E A B C K f L N I J P Q R S"},E:{"1":"7 9 D G E A B C K ZB aB bB PB fB","4":"F O H WB RB YB"},F:{"1":"0 1 2 3 4 5 6 9 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","2":"E gB hB","4":"7 B C iB jB GB lB"},G:{"1":"G qB rB SB tB uB vB wB xB yB zB 0B 1B 2B","4":"RB mB CB oB pB"},H:{"4":"3B"},I:{"1":"QB 8B 9B","4":"OB F 4B 5B 6B 7B CB"},J:{"1":"A","4":"D"},K:{"1":"M","4":"7 9 A B C GB"},L:{"1":"q"},M:{"1":"8"},N:{"4":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"4":"IC"}},B:5,C:"CSS3 Overflow-wrap"};
