module.exports={A:{A:{"2":"H D G E nB","130":"A B"},B:{"130":"C K f L N I J q"},C:{"1":"0 1 2 3 4 5 6 8 e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB eB dB","130":"F O H D G E A B C K f L N I J P Q R S T","322":"U V W X Y Z a b c d"},D:{"2":"F O H D G E A B C K f L","130":"0 1 2 3 4 5 6 8 N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"1":"7 9 A B C K bB PB fB","2":"D G E WB RB ZB aB","130":"F O H YB"},F:{"2":"7 9 E B C gB hB iB jB GB lB","130":"0 1 2 3 4 5 6 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z"},G:{"1":"tB uB vB wB xB yB zB 0B 1B 2B","2":"G RB qB rB SB","130":"mB CB oB pB"},H:{"2":"3B"},I:{"2":"OB F 4B 5B 6B 7B CB","130":"QB 8B 9B"},J:{"2":"D","130":"A"},K:{"2":"7 9 A B C GB","130":"M"},L:{"130":"q"},M:{"1":"8"},N:{"2":"A B"},O:{"130":"AC"},P:{"130":"F BC CC DC EC FC PB"},Q:{"130":"GC"},R:{"130":"HC"},S:{"1":"IC"}},B:4,C:"CSS font-variant-alternates"};
