module.exports={A:{A:{"2":"H D G E A B nB"},B:{"2":"C K f L N I J","1348":"q"},C:{"16":"kB OB eB dB","548":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB"},D:{"16":"F O H D G E A B C K f","164":"0 1 2 3 4 5 6 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB","1348":"8 DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"2":"F WB RB","16":"O","164":"H D G YB ZB aB","257":"7 9 E A B C K bB PB fB"},F:{"2":"7 9 E B C gB hB iB jB GB lB","164":"L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v","1220":"0 1 2 3 4 5 6 w x y z"},G:{"16":"RB mB CB oB pB","164":"G qB rB","257":"SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"16":"OB 4B 5B 6B","164":"F QB 7B CB 8B 9B"},J:{"16":"D","164":"A"},K:{"2":"7 9 A B C GB","164":"M"},L:{"1220":"q"},M:{"548":"8"},N:{"2":"A B"},O:{"164":"AC"},P:{"164":"F BC CC DC EC FC PB"},Q:{"164":"GC"},R:{"164":"HC"},S:{"548":"IC"}},B:5,C:":matches() CSS pseudo-class"};
