module.exports={A:{A:{"1":"H D G E A B","16":"nB"},B:{"1":"C K f L N I J q"},C:{"1":"0 1 2 3 4 5 6 8 H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB F O eB dB"},D:{"1":"5 6 8 DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"0 1 2 3 4 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB"},E:{"2":"7 9 F O H D G E A B C K WB RB YB ZB aB bB PB fB"},F:{"1":"0 1 2 3 4 5 6 u v w x y z","2":"7 9 E B C L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t gB hB iB jB GB lB"},G:{"2":"G RB mB CB oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"2":"OB F QB 4B 5B 6B 7B CB 8B 9B"},J:{"16":"D A"},K:{"2":"7 9 A B C M GB"},L:{"1":"q"},M:{"1":"8"},N:{"16":"A B"},O:{"16":"AC"},P:{"2":"BC CC DC EC FC PB","16":"F"},Q:{"2":"GC"},R:{"2":"HC"},S:{"1":"IC"}},B:2,C:"Printing Events"};
