module.exports={A:{A:{"2":"H D G E nB","132":"B","164":"A"},B:{"1":"q","132":"C K f L N I J"},C:{"2":"0 1 2 3 4 5 6 8 kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB eB dB"},D:{"1":"0 1 2 3 4 5 6 8 EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y","260":"z"},E:{"2":"7 9 F O H D G E A B C K WB RB YB ZB aB bB PB fB"},F:{"1":"0 1 2 3 4 5 6 n o p M r s t u v w x y z","2":"7 9 E B C L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l gB hB iB jB GB lB","260":"m"},G:{"2":"G RB mB CB oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"1":"QB","2":"OB F 4B 5B 6B 7B CB 8B 9B"},J:{"2":"D A"},K:{"2":"7 9 A B C M GB"},L:{"1":"q"},M:{"2":"8"},N:{"132":"B","164":"A"},O:{"2":"AC"},P:{"1":"BC CC DC EC FC PB","16":"F"},Q:{"2":"GC"},R:{"1":"HC"},S:{"2":"IC"}},B:5,C:"CSS touch-action level 2 values"};
