module.exports={A:{A:{"1":"A B","16":"nB","900":"H D G E"},B:{"1":"q","1025":"C K f L N I J"},C:{"1":"0 1 2 3 4 5 6 8 v w x y z EB NB DB BB FB HB IB JB KB LB MB","900":"kB OB eB dB","1025":"F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u"},D:{"1":"0 1 2 3 4 5 6 8 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB"},E:{"1":"7 9 H D G E A B C K YB ZB aB bB PB fB","16":"O WB","900":"F RB"},F:{"1":"0 1 2 3 4 5 6 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","16":"E","132":"7 9 B C gB hB iB jB GB lB"},G:{"1":"mB CB oB pB qB SB tB uB vB wB xB yB zB 0B 1B 2B","16":"RB","2052":"G rB"},H:{"132":"3B"},I:{"1":"OB F 6B 7B CB 8B 9B","16":"4B 5B","4097":"QB"},J:{"1":"D A"},K:{"132":"7 9 A B C GB","4100":"M"},L:{"4097":"q"},M:{"4097":"8"},N:{"1":"A B"},O:{"1":"AC"},P:{"4097":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"1025":"IC"}},B:1,C:"maxlength attribute for input and textarea elements"};
