module.exports={A:{A:{"2":"H D G E A B nB"},B:{"1":"J q","2":"C K f L N I"},C:{"1":"8 DB BB FB HB IB JB KB LB MB","2":"kB OB eB dB","8":"0 1 2 3 4 5 6 F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB"},D:{"1":"0 1 2 3 4 5 6 8 c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F O","8":"H D G","132":"E A B C K f L N I J P Q R S","260":"T U V W X Y Z a b"},E:{"2":"7 9 F O H D G E A B C K WB RB YB ZB aB bB PB fB"},F:{"1":"0 1 2 3 4 5 6 P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","2":"E gB hB iB","8":"B jB","132":"7 GB lB","260":"9 C L N I J"},G:{"2":"G RB mB CB oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"1":"3B"},I:{"1":"QB CB 8B 9B","2":"OB 4B 5B 6B","132":"F 7B"},J:{"2":"D A"},K:{"1":"7 9 C M GB","2":"A","132":"B"},L:{"1":"q"},M:{"1":"8"},N:{"2":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"8":"IC"}},B:7,C:"WebP image format"};
