module.exports={A:{A:{"2":"nB","8":"H D G E A B"},B:{"1":"q","8":"C K f L N I J"},C:{"1":"0 1 2 3 4 5 6 8 V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB","8":"OB F O H D G E A B C K f L N I J P Q R S T U eB dB"},D:{"1":"0 1 2 3 4 5 6 8 Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F O H D G E A B C K","8":"f L N I J P"},E:{"1":"7 9 H D G E A B C K ZB aB bB PB fB","2":"WB RB","8":"F O YB"},F:{"1":"0 1 2 3 4 5 6 L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","2":"E B gB hB iB jB","8":"7 9 C GB lB"},G:{"1":"G pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B","2":"RB","8":"mB CB oB"},H:{"2":"3B"},I:{"1":"QB 8B 9B","8":"OB F 4B 5B 6B 7B CB"},J:{"1":"A","8":"D"},K:{"1":"M","2":"A B","8":"7 9 C GB"},L:{"1":"q"},M:{"1":"8"},N:{"8":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"1":"IC"}},B:1,C:"srcdoc attribute for iframes"};
