module.exports={A:{A:{"2":"H D G E A B nB"},B:{"1":"f L N I J q","2":"C K"},C:{"1":"0 1 2 3 4 5 6 8 S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB","2":"kB OB F O H D G E A B C K f L N I J P Q R eB dB"},D:{"1":"0 1 2 3 4 5 6 8 S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F","36":"O H D G E A B C K f L N I J P Q R"},E:{"1":"7 9 H D G E A B C K ZB aB bB PB fB","2":"F O WB RB YB"},F:{"1":"0 1 2 3 4 5 6 V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z","2":"7 9 E B C L N I J P Q R S T U gB hB iB jB GB lB"},G:{"2":"G RB mB CB oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"2":"OB F 4B 5B 6B 7B CB","36":"QB 8B 9B"},J:{"1":"A","2":"D"},K:{"2":"7 9 A B C GB","36":"M"},L:{"513":"q"},M:{"1":"8"},N:{"2":"A B"},O:{"2":"AC"},P:{"36":"F","258":"BC CC DC EC FC PB"},Q:{"2":"GC"},R:{"258":"HC"},S:{"1":"IC"}},B:1,C:"Web Notifications"};
