module.exports={A:{A:{"2":"H D G E A B nB"},B:{"1":"K f L N I J q","132":"C"},C:{"2":"kB OB F O H D G E A B C K f L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w eB dB","1090":"0 x y z","2052":"1 2 3 4 5 6 8 EB NB DB BB FB HB IB JB KB LB MB"},D:{"1":"0 1 2 3 4 5 6 8 V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z EB NB DB BB FB HB IB JB KB LB MB cB QB XB TB q sB UB VB","2":"F O H D G E A B C K f L N I J P","2052":"Q R S T U"},E:{"2":"7 9 F O H D G E A B C K WB RB YB ZB aB bB PB fB"},F:{"1":"0 1 2 3 4 5 6 7 9 E B C L N I J P Q R S T U V W X Y Z a b c d e AB g h i j k l m n o p M r s t u v w x y z gB hB iB jB GB lB"},G:{"2":"RB mB CB","260":"G oB pB qB rB SB tB uB vB wB xB yB zB 0B 1B 2B"},H:{"2":"3B"},I:{"1":"QB 8B 9B","2":"OB 4B 5B 6B","514":"F 7B CB"},J:{"1":"A","2":"D"},K:{"1":"7 9 A B C M GB"},L:{"1":"q"},M:{"1":"8"},N:{"2":"A B"},O:{"1":"AC"},P:{"1":"F BC CC DC EC FC PB"},Q:{"1":"GC"},R:{"1":"HC"},S:{"2052":"IC"}},B:1,C:"Date and time input types"};
